@@ -1,10 +1,10 @@
 from importlib import import_module, invalidate_caches as importlib_invalidate_caches
-from logging import basicConfig, INFO
 from pkgutil import walk_packages
 
-from rich.logging import RichHandler
 from typer import Typer
 
+from deckz.utils import setup_logging
+
 
 app = Typer(
     help="Tool to handle a large number of beamer decks, "
@@ -14,12 +14,7 @@ app = Typer(
 
 
 def main() -> None:
-    basicConfig(
-        level=INFO,
-        format="%(message)s",
-        datefmt="%H:%M:%S",
-        handlers=[RichHandler(rich_tracebacks=True)],
-    )
+    setup_logging()
     _import_module_and_submodules(__name__)
     app()
 
