@@ -3,7 +3,7 @@ from pathlib import Path
 
 from deckz.cli import app
 from deckz.paths import Paths
-from deckz.uploader import Uploader
+from deckz.uploading import Uploader
 
 
 _logger = getLogger(__name__)
